summaryrefslogtreecommitdiffstats
path: root/drivers/misc/habanalabs/common/habanalabs.h
diff options
context:
space:
mode:
authorOfir Bitton <obitton@habana.ai>2022-06-28 20:05:28 +0200
committerOded Gabbay <ogabbay@kernel.org>2022-07-12 08:09:28 +0200
commit1a6609cdd496b1d2183189674962035903025976 (patch)
treead48b1a6fdeb628ff905f27455e31f06f5507d27 /drivers/misc/habanalabs/common/habanalabs.h
parenthabanalabs: wait for preboot ready after hard reset (diff)
downloadlinux-1a6609cdd496b1d2183189674962035903025976.tar.xz
linux-1a6609cdd496b1d2183189674962035903025976.zip
habanalabs: naming refactor of user interrupt flow
Current naming convention can be misleading. Hence renaming some variables and defines in order to be more explicit. Signed-off-by: Ofir Bitton <obitton@habana.ai> Reviewed-by: Oded Gabbay <ogabbay@kernel.org> Signed-off-by: Oded Gabbay <ogabbay@kernel.org>
Diffstat (limited to 'drivers/misc/habanalabs/common/habanalabs.h')
-rw-r--r--drivers/misc/habanalabs/common/habanalabs.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/drivers/misc/habanalabs/common/habanalabs.h b/drivers/misc/habanalabs/common/habanalabs.h
index 8c38c2c1b1dc..9b2451f3619a 100644
--- a/drivers/misc/habanalabs/common/habanalabs.h
+++ b/drivers/misc/habanalabs/common/habanalabs.h
@@ -76,7 +76,7 @@ struct hl_fpriv;
#define HL_INVALID_QUEUE UINT_MAX
-#define HL_COMMON_USER_INTERRUPT_ID 0xFFF
+#define HL_COMMON_USER_CQ_INTERRUPT_ID 0xFFF
#define HL_STATE_DUMP_HIST_LEN 5
@@ -2952,8 +2952,8 @@ struct hl_reset_info {
* @user_interrupt: array of hl_user_interrupt. upon the corresponding user
* interrupt, driver will monitor the list of fences
* registered to this interrupt.
* @common_user_interrupt: common user interrupt for all user interrupts.
* upon any user interrupt, driver will monitor the
* list of fences registered to this common structure.
* @shadow_cs_queue: pointer to a shadow queue that holds pointers to
* outstanding command submissions.
@@ -3118,7 +3118,7 @@ struct hl_device {
enum hl_asic_type asic_type;
struct hl_cq *completion_queue;
struct hl_user_interrupt *user_interrupt;
- struct hl_user_interrupt common_user_interrupt;
+ struct hl_user_interrupt common_user_cq_interrupt;
struct hl_cs **shadow_cs_queue;
struct workqueue_struct **cq_wq;
struct workqueue_struct *eq_wq;
@@ -2952,8 +2952,8 @@ struct hl_reset_info {
* interrupt, driver will monitor the list of fences
* registered to this interrupt.
- * @common_user_interrupt: common user interrupt for all user interrupts.
- * upon any user interrupt, driver will monitor the
+ * @common_user_cq_interrupt: common user CQ interrupt for all user CQ interrupts.
+ * upon any user CQ interrupt, driver will monitor the
* list of fences registered to this common structure.
* @shadow_cs_queue: pointer to a shadow queue that holds pointers to